$!
$! MAKEGZIP.COM
$! Re-Written By:  Robert Alan Byer
$!                 byer@mail.ourservers.net
$!
$!
$! This script is used to compile and link GZIP v1.2.4a for OpenVMS using 
$! DEC C.
$!
$! The script accepts the following parameters.
$!
$!	P1	DEBUG		Build With Debugger Information.
$!		NODEBUG		Build Withoug Debugger Information.
$!
$! The default is "NODEBUG".
$!
$!
$! Check To Make Sure We Have Valid Command Line Parameters.
$!
$ GOSUB CHECK_OPTIONS
$!
$! Check To See If We Are On An AXP Machine.
$!
$ IF (F$GETSYI("CPU").LT.128)
$ THEN
$!
$!  We Are On A VAX Machine So Tell The User.
$!
$   WRITE SYS$OUTPUT "Compiling On A VAX Machine."
$!
$!  Define The Machine Type.
$!
$   MACHINE_TYPE = "VAX"
$!
$!  Define The Compile Command For VAX.
$!
$ CC = "CC/DECC/''OPTIMIZE'/''DEBUGGER'/DEFINE=(VMS,RCSID)" + -
       "/PREFIX=(ALL,EXCEPT=(GETOPT,OPTARG,OPTOPT,OPTIND,OPTERR,BASENAME))"
$!
$!  Define The GZIP Library Name.
$!
$   GZIPLIB_NAME = "SYS$DISK:[]GZIPLIB-VAX.OLB"
$!
$! Else, We Are On An AXP Machine.
$!
$ ELSE
$!
$!  We Are On A AXP Machine So Tell The User.
$!
$   WRITE SYS$OUTPUT "Compiling On A AXP Machine."
$!
$!  Define The Machine Type.
$!
$   MACHINE_TYPE = "AXP"
$!
$!  Define The Compile Command For AXP.
$!
$ CC ="CC/DECC/''DEBUGGER'/''OPTIMIZE'/DEFINE=(VMS,RCSID)" + -
      "/PREFIX=(ALL,EXCEPT=(GETOPT,OPTARG,OPTOPT,OPTIND,OPTERR,BASENAME))" 
$!
$!  Define The GZIPLIB Library Name.
$!
$   GZIPLIB_NAME = "SYS$DISK:[]GZIPLIB-AXP.OLB"
$!
$! End Of The Machine Check.
$!
$ ENDIF
$!
$! Build The GZIPLIB Library.
$!
$ BUILD_GZIPLIB:
$!
$! Tell The User What We Are Doing.
$!
$ WRITE SYS$OUTPUT ""
$ WRITE SYS$OUTPUT "Compling The ",GZIPLIB_NAME," Library."
$ WRITE SYS$OUTPUT "Using Compile Command: ",CC
$ WRITE SYS$OUTPUT ""
$!
$! Check To See If We Already Have A "GZIPLIB-xxx.OLB" Library...
$!
$ IF (F$SEARCH(GZIPLIB_NAME).EQS."")
$ THEN
$!
$!  Guess Not, Create The Library.
$!
$   LIBRARY/CREATE/OBJECT 'GZIPLIB_NAME'
$!
$! End The Library Check.
$!
$ ENDIF
$!
$! Check To Make Sure We Have The VMS.C File.
$!
$ 
$ IF (F$SEARCH("SYS$DISK:[.VMS]VMS.C").EQS."")
$ THEN
$!
$!  Tell The User We Can't Find The "SYS$DISK:[.VMS]VMS.C" File, So We Are 
$!  Gong To Exit As We Can't Compile Without It.
$!
$   WRITE SYS$OUTPUT ""
$   WRITE SYS$OUTPUT "Can't Find The SYS$DISK:[.VMS]VMS.C File.  Since It's"
$   WRITE SYS$OUTPUT "Needed To Build GZIP.EXE We Will Exit Now."
$   WRITE SYS$OUTPUT ""
$!
$!  Since We Can't Compile Without, Time To Exit.
$!
$   EXIT
$!
$! End The SYS$DISK:[.VMS]VMS.C File Check.
$!
$ ENDIF
$!
$! Tell The User We Are Compiling VMS.C.
$!
$  WRITE SYS$OUTPUT "	SYS$DISK:[.VMS]VMS.C"
$!
$! Compile The File.
$!
$  CC/INCLUDE=(SYS$DISK:[])/OBJECT=SYS$DISK:[]VMS.OBJ SYS$DISK:[.VMS]VMS.C
$!
$! Add SYS$DISK:[.VMS]VMS.C To The Library.
$!
$ LIBRARY/REPLACE/OBJECT 'GZIPLIB_NAME' SYS$DISK:[]VMS.OBJ
$!
$! Check To Make Sure We Have The GZIP.C File.
$!
$ 
$ IF (F$SEARCH("SYS$DISK:[]GZIP.C").EQS."")
$ THEN
$!
$!  Tell The User We Can't Find The "GZIP.C" File, So We Are Gong To
$!  Exit As We Can't Compile Without It.
$!
$   WRITE SYS$OUTPUT ""
$   WRITE SYS$OUTPUT "Can't Find The SYS$DISK:[]GZIP.C File.  Since It's"
$   WRITE SYS$OUTPUT "Needed To Build GZIP.EXE We Will Exit Now."
$   WRITE SYS$OUTPUT ""
$!
$!  Since We Can't Compile Without, Time To Exit.
$!
$   EXIT
$!
$! End The SYS$DISK:[]GZIP.C File Check.
$!
$ ENDIF
$!
$! Tell The User We Are Compiling GZIP.C.
$!
$  WRITE SYS$OUTPUT "	SYS$DISK:[]GZIP.C"
$!
$! Compile The File.
$!
$  CC/OBJECT=SYS$DISK:[]GZIP.OBJ SYS$DISK:[]GZIP.C
$!
$! Define The Files That Are Necessary For The GZIPLIB Library.
$!
$ GZIPLIB_FILES = "ZIP,DEFLATE,TREES,BITS,UNZIP,INFLATE,UTIL,CRYPT," + -
                  "LZW,UNLZW,UNPACK,UNLZH,GETOPT"
$!
$!  Define A File Counter And Set It To "0".
$!
$ GZIPLIB_FILE_COUNTER = 0
$!
$! Top Of The File Loop.
$!
$ NEXT_GZIPLIB_FILE:
$!
$! O.K, Extract The File Name From The File List.
$!
$ GZIPLIB_FILE_NAME = F$ELEMENT(GZIPLIB_FILE_COUNTER,",",GZIPLIB_FILES)
$!
$! Check To See If We Are At The End Of The File List.
$!
$ IF (GZIPLIB_FILE_NAME.EQS.",") THEN GOTO GZIPLIB_FILE_DONE
$!
$! Increment The Counter.
$!
$ GZIPLIB_FILE_COUNTER = GZIPLIB_FILE_COUNTER + 1
$!
$! Create The Source File Name.
$!
$ GZIPLIB_SOURCE_FILE = "SYS$DISK:[]" + GZIPLIB_FILE_NAME + ".C"
$!
$! Create The Object File Name.
$!
$ GZIPLIB_OBJECT_FILE = "SYS$DISK:[]" + GZIPLIB_FILE_NAME + ".OBJ"
$!
$! Check To See If The File We Want To Compile Actually Exists.
$!
$ IF (F$SEARCH(GZIPLIB_SOURCE_FILE).EQS."")
$ THEN
$!
$!  Tell The User That The File Dosen't Exist.
$!
$   WRITE SYS$OUTPUT ""
$   WRITE SYS$OUTPUT "The File ",GZIPLIB_SOURCE_FILE," Dosen't Exist."
$   WRITE SYS$OUTPUT ""
$!
$!  Exit The Build.
$!
$   EXIT
$!
$! End The File Check.
$!
$ ENDIF
$!
$! Tell The User What We Are Compiling.
$!
$  WRITE SYS$OUTPUT "	",GZIPLIB_SOURCE_FILE
$!
$! Compile The File.
$!
$  CC/OBJECT='GZIPLIB_OBJECT_FILE' 'GZIPLIB_SOURCE_FILE'
$!
$! Add It To The Library.
$!
$ LIBRARY/REPLACE/OBJECT 'GZIPLIB_NAME' 'GZIPLIB_OBJECT_FILE'
$!
$! Go Back And Do It Again.
$!
$ GOTO NEXT_GZIPLIB_FILE
$!
$! All Done Compiling.
$!
$ GZIPLIB_FILE_DONE:
$!
$! Link GZIP.
$!
$ LINK/'DEBUGGER'/'TRACEBACK'/EXE=SYS$DISK:[]GZIP.EXE-'MACHINE_TYPE' -
      SYS$DISK:[]GZIP.OBJ,SYS$DISK:[]VMS.OBJ,'GZIPLIB_NAME'/LIBRARY
$!
$! Delete The Object Files.
$!
$ DELETE/NOCONFIRM/NOLOG SYS$DISK:[]*.OBJ;*
$!
$! That's It, Time To EXIT.
$!
$ EXIT
$!
$! Check The User's Options.
$!
$ CHECK_OPTIONS:
$!
$! Check To See If We Are To Compile Without Debugger Information.
$!
$ IF ((P1.EQS."").OR.(P1.EQS."NODEBUG"))
$ THEN
$!
$!  P1 Is Either Blank Or "NODEBUG" So Compile Without Debugger Information.
$!
$   DEBUGGER  = "NODEBUG"
$!
$!  Check To See If We Are On An AXP Machine.
$!
$   IF (F$GETSYI("CPU").LT.128)
$   THEN
$!
$!    We Are On A VAX Machine So Define The VAX Optimize Parameters.
$!
$     OPTIMIZE = "OPTIMIZE"
$!
$!  Else....
$!
$   ELSE
$!
$!    Else We Are On An AXP So Define The AXP Optimize Parameters.
$!
$     OPTIMIZE = "ASSUME=WHOLE/PLUS/OPTIMIZE=(LEVEL=5,TUNE=HOST)"
$!
$!  Time To End The Machine Check.
$!
$   ENDIF
$!
$!  Define The Linker Traceback Parameters.
$!
$   TRACEBACK = "NOTRACEBACK"
$!
$!  Tell The User What They Selected.
$!
$   WRITE SYS$OUTPUT ""
$   WRITE SYS$OUTPUT "No Debugger Information Will Be Produced During Compile."
$   WRITE SYS$OUTPUT "Compiling With Compiler Optimization."
$ ELSE
$!
$!  Check To See If We Are To Compile With Debugger Information.
$!
$   IF (P1.EQS."DEBUG")
$   THEN
$!
$!    Compile With Debugger Information.
$!
$     DEBUGGER  = "DEBUG"
$     OPTIMIZE = "NOOPTIMIZE"
$     TRACEBACK = "TRACEBACK"
$!
$!    Tell The User What They Selected.
$!
$     WRITE SYS$OUTPUT ""
$     WRITE SYS$OUTPUT "Debugger Information Will Be Produced During Compile."
$     WRITE SYS$OUTPUT "Compiling Without Compiler Optimization."
$!
$!  Else...
$!
$   ELSE
$!
$!    Tell The User Entered An Invalid Option..
$!
$     WRITE SYS$OUTPUT ""
$     WRITE SYS$OUTPUT "The Option ",P1," Is Invalid.  The Valid Options Are:"
$     WRITE SYS$OUTPUT ""
$     WRITE SYS$OUTPUT "    DEBUG    :  Compile With The Debugger Information."
$     WRITE SYS$OUTPUT "    NODEBUG  :  Compile Without The Debugger Information."
$     WRITE SYS$OUTPUT ""
$!
$!    Time To EXIT.
$!
$     EXIT
$   ENDIF
$ ENDIF
$!
$! Time To Return To Where We Were.
$!
$ RETURN
